<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>たった今</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1件の新しいメッセージ</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1分前</translation>
    </message>
</context>
</TS>